OSDN Git Service

update docs for 1.4.8
[howm/howm.git] / howm.el
diff --git a/howm.el b/howm.el
index 33fb7cb..3c44664 100644 (file)
--- a/howm.el
+++ b/howm.el
@@ -1,22 +1,28 @@
 ;;; howm.el --- Wiki-like note-taking tool
-;;; Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2015, 2016
-;;;   HIRAOKA Kazuyuki <khi@users.sourceforge.jp>
-;;; $Id: howm.el,v 1.22 2011-12-31 15:07:29 hira Exp $
-;;;
-;;; This program is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 1, or (at your option)
-;;; any later version.
-;;;
-;;; This program is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; The GNU General Public License is available by anonymouse ftp from
-;;; prep.ai.mit.edu in pub/gnu/COPYING.  Alternately, you can write to
-;;; the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,
-;;; USA.
+;;; -*- Emacs-Lisp -*-
+;;; howm.el.  Generated from howm.el.in by configure.
+
+;; Copyright (C) 2002, 2003, 2004, 2005-2021 HIRAOKA Kazuyuki
+
+;; Author: HIRAOKA Kazuyuki <khi@users.osdn.me>
+;; URL: https://howm.osdn.jp
+;; Version: 1.4.8-snapshot3
+;; Package-Requires: ((cl-lib "0.5"))
+
+;; This program is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 1, or (at your option)
+;; any later version.
+
+;; This program is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+
+;; The GNU General Public License is available by anonymouse ftp from
+;; prep.ai.mit.edu in pub/gnu/COPYING.  Alternately, you can write to
+;; the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,
+;; USA.
 ;;--------------------------------------------------------------------
 
 ;;; DESCRIPTION:
@@ -24,6 +30,8 @@
 ;;; See README.
 ;;; HOWM is acronym of "Hitori Otegaru Wiki Modoki".
 
+(defconst howm-version "1.4.8-snapshot3")
+
 ;; Files [0]-[3] have only hierarchical dependencies,
 ;; whereas files in [5] have circular dependencies.
 ;; Each file in [5] provides itself first,
@@ -40,7 +48,6 @@
 
 ;;; [2] howm basic libraries
 
-(require 'howm-version)
 (require 'howm-vars)
 (require 'howm-common)
 
@@ -75,6 +82,7 @@
 ;;; http://noir.s7.xrea.com/pub/zaurus/howmz.el
 
 (howm-require-lang 'en)
+(howm-require-lang 'fr)
 (howm-require-lang 'ja)
 
 ;;; security fix [2006-12-16]